"use strict";

const fs = require("fs-extra");
const path = require("path");
const mime = require("mime-types");
const set = require("lodash.set");
const {
  categories, authors, articles,
  // global, about,
} = require("../data/data.json");

async function isFirstRun() {
  const pluginStore = strapi.store({
    environment: strapi.config.environment,
    type: "type",
    name: "setup",
  });
  const initHasRun = await pluginStore.get({ key: "initHasRun" });
  await pluginStore.set({ key: "initHasRun", value: true });
  return !initHasRun;
}

// async function setInitPermissions(roleType, newPermissions) {
//   // Find the ID of the role
//   const role = await strapi
//     .query("plugin::users-permissions.role")
async function setPublicPermissions(newPermissions) {
  // Find the ID of the public role
  const publicRole = await strapi
    .query('plugin::users-permissions.role')
    .findOne({
      where: {
        // type: roleType,
        type: 'public',
      },
    });

  // // Create the new permissions and link them to the role
  // const allPermissionsToCreate = [];
  // Create the new permissions and link them to the public role
  const allPermissionsToCreate = []
  Object.keys(newPermissions).map((controller) => {
    const actions = newPermissions[controller];
    const permissionsToCreate = actions.map((action) => {
      return strapi.query("plugin::users-permissions.permission").create({
        data: {
          action: `api::${controller}.${controller}.${action}`,
          // role: role.id,
          role: publicRole.id,
        },
      });
    });
    allPermissionsToCreate.push(...permissionsToCreate);
  });
  await Promise.all(allPermissionsToCreate);
}

// async function setInitFrontendAPIToken(attributes) {
//   const apiTokenService = strapi.service(`admin::api-token`);
//   const apiToken = await apiTokenService.create(attributes);
//   const accessKey = apiToken.accessKey;
//   const credentialsLocation = "frontend.env.development"
//   const apiUrl = 'http://localhost:1337'
//   // /** DEBUG */
//   // console.log('[DEBUG] accessKey');
//   // console.log(accessKey);
//   // console.log('[DEBUG] credentialsLocation: ');
//   // console.log(credentialsLocation);
//   fs.writeFile(credentialsLocation, `STRAPI_API_URL=${apiUrl}\nSTRAPI_TOKEN=${accessKey}`, function (err) {
//     if (err) return console.log(err);
//     console.log('Frontend .env file updated.');
//   });
// }

function getFileSizeInBytes(filePath) {
  const stats = fs.statSync(filePath);
  const fileSizeInBytes = stats["size"];
  return fileSizeInBytes;
}

function getFileData(fileName) {
  const filePath = path.join("data", "uploads", fileName);
  // Parse the file metadata
  const size = getFileSizeInBytes(filePath);
  const ext = fileName.split(".").pop();
  const mimeType = mime.lookup(ext);

  return {
    path: filePath,
    name: fileName,
    size,
    type: mimeType,
  };
}

async function uploadFile(file, name) {
  return strapi
    .plugin("upload")
    .service("upload")
    .upload({
      files: file,
      data: {
        fileInfo: {
          alternativeText: `An image uploaded to Strapi called ${name}`,
          caption: name,
          name,
        },
      },
    });
}

// Create an entry and attach files if there are any
async function createEntry({ model, entry }) {
  try {
    // Actually create the entry in Strapi
    await strapi.entityService.create(`api::${model}.${model}`, {
      data: entry,
    });
  } catch (error) {
    console.error({ model, entry, error });
  }
}

async function checkFileExistsBeforeUpload(files) {
  const existingFiles = [];
  const uploadedFiles = [];
  const filesCopy = [...files];

  for (const fileName of filesCopy) {
    // Check if the file already exists in Strapi
    const fileWhereName = await strapi.query("plugin::upload.file").findOne({
      where: {
        name: fileName,
      },
    });

    if (fileWhereName) {
      // File exists, don't upload it
      existingFiles.push(fileWhereName);
    } else {
      // File doesn't exist, upload it
      const fileData = getFileData(fileName);
      const fileNameNoExtension = fileName.split('.').shift()
      const [file] = await uploadFile(fileData, fileNameNoExtension);
      uploadedFiles.push(file);
    }
  }
  const allFiles = [...existingFiles, ...uploadedFiles];
  // If only one file then return only that file
  return allFiles.length === 1 ? allFiles[0] : allFiles;
}

// async function updateBlocks(blocks) {
//   const updatedBlocks = [];
//   for (const block of blocks) {
//     if (block.__component === "shared.media") {
//       const uploadedFiles = await checkFileExistsBeforeUpload([block.file]);
//       // Copy the block to not mutate directly
//       const blockCopy = { ...block };
//       // Replace the file name on the block with the actual file
//       blockCopy.file = uploadedFiles;
//       updatedBlocks.push(blockCopy);
//     } else if (block.__component === "shared.slider") {
//       // Get files already uploaded to Strapi or upload new files
//       const existingAndUploadedFiles = await checkFileExistsBeforeUpload(
//         block.files
//       );
//       // Copy the block to not mutate directly
//       const blockCopy = { ...block };
//       // Replace the file names on the block with the actual files
//       blockCopy.files = existingAndUploadedFiles;
//       // Push the updated block
//       updatedBlocks.push(blockCopy);
//     } else {
//       // Just push the block as is
//       updatedBlocks.push(block);
//     }
//   }
// 
//   return updatedBlocks;
// }

async function importArticles() {
  for (const article of articles) {
    // const cover = await checkFileExistsBeforeUpload([`${article.slug}.jpg`]);
    // const updatedBlocks = await updateBlocks(article.blocks);
    const thumbnail = await checkFileExistsBeforeUpload([`${article.slug}.jpg`])

    await createEntry({
      model: "article",
      entry: {
        ...article,
        // cover,
        // blocks: updatedBlocks,
        // // Make sure it's not a draft
        // publishedAt: Date.now(),
        thumbnail,
      },
    });
  }
}

// async function importGlobal() {
//   const favicon = await checkFileExistsBeforeUpload(["favicon.png"]);
//   const shareImage = await checkFileExistsBeforeUpload(["default-image.png"])
//   return createEntry({
//     model: "global",
//     entry: {
//       ...global,
//       favicon,
//       // Make sure it's not a draft
//       publishedAt: Date.now(),
//       defaultSeo: {
//         ...global.defaultSeo,
//         shareImage
//       }
//     },
//   });
// }
// 
// async function importAbout() {
//   const updatedBlocks = await updateBlocks(about.blocks);
// 
//   await createEntry({
//     model: "about",
//     entry: {
//       ...about,
//       blocks: updatedBlocks,
//       // Make sure it's not a draft
//       publishedAt: Date.now(),
//     },
//   });
// }

async function importCategories() {
  for (const category of categories) {
    // await createEntry({ model: "category", entry: category });
    const icon = await checkFileExistsBeforeUpload([`${category.slug}.svg`])

    await createEntry({
      model: 'category',
      entry: {
        ...category,
        icon,
      },
    })
  }
}

async function importAuthors() {
  for (const author of authors) {
    // const avatar = await checkFileExistsBeforeUpload([author.avatar]);
    const thumbnail = await checkFileExistsBeforeUpload([`${author.slug}.png`])

    await createEntry({
      model: "author",
      entry: {
        ...author,
        // avatar,
        thumbnail,
      },
    });
  }
}

async function importSeedData() {

  /** Allow read of application content types */
  await setPublicPermissions({
    article: ["find", "findOne"],
    category: ["find", "findOne"],
    author: ["find", "findOne"],
  })

  // // Initial demo permissions.
  // const initPermissions = {
  //   article: ["find", "findOne"],
  //   category: ["find", "findOne"],
  //   author: ["find", "findOne"],
  //   // global: ["find", "findOne"],
  //   // about: ["find", "findOne"],
  // }
  // 
  // // Initialize public permissions.
  // await setInitPermissions("public", initPermissions)
  // 
  // // Initialize authenticated permissions.
  // await setInitPermissions("authenticated", initPermissions)
  //
  // // Creating initial demo API token for the frontend.
  // await setInitFrontendAPIToken({
  //   type: 'full-access',
  //   name: 'Full-Access Strapi API Token',
  //   description: 'Token generated by the Strapi Template to be used by a Starter'
  // })

  /** Create all entries */
  await importCategories();
  await importAuthors();
  await importArticles();
  // await importGlobal();
  // await importAbout();
}

module.exports = async () => {
  const shouldImportSeedData = await isFirstRun();

  if (shouldImportSeedData) {
    try {
      console.log("Setting up the template...");
      await importSeedData();
      console.log("Ready to go");
    } catch (error) {
      console.log("Could not import seed data");
      console.error(error);
    }
  }
};
